@@ -1,8 +1,8 @@
 import click
 
 
-from .resize import resize
-from .info import info
+#from .resize import resize
+#from .info import info
 from .removebg import removebg
 
 
